@@ -41,7 +41,7 @@ class Download:
 
         logger.info("Start Download",
                     extra={'task': self.task,
-                           'scraper_name': self.scraper.config['SCRAPER_NAME'],
+                           **self.scraper.log_extras(),
                            'time_started': self.time_downloaded,
                            })
 
@@ -118,7 +118,7 @@ class Download:
         except Exception:
             logger.exception("Download Exception",
                              extra={'task': self.task,
-                                    'scraper_name': self.scraper.config['SCRAPER_NAME']})
+                                    **self.scraper.log_extras()})
         else:
             if self._manifest['source_files']:
                 self._save_metadata()
@@ -132,13 +132,13 @@ class Download:
                 # If it got here and there is not saved file then thats an issue
                 logger.error("No source file saved",
                              extra={'task': self.task,
-                                    'scraper_name': self.scraper.config['SCRAPER_NAME'],
+                                    **self.scraper.log_extras(),
                                     'manifest': self._manifest,
                                     })
 
         logger.debug('Download finished',
                      extra={'task': self.task,
-                            'scraper_name': self.scraper.config['SCRAPER_NAME'],
+                            **self.scraper.log_extras(),
                             'time_finished': datetime.datetime.utcnow().isoformat() + 'Z',
                             })
 
@@ -173,6 +173,8 @@ class Download:
                 'file': source_file,
                 'request': {
                     'url': r.url,
+                    'method': r.request.method,
+                    'status_code': r.status_code,
                     'headers': {
                         'request': dict(r.request.headers),
                         'response': dict(r.headers),
@@ -197,7 +199,7 @@ class Download:
                 filename = metadata['download_manifest']['source_files'][0]['file']
                 logger.debug("Saving metadata file",
                              extra={'task': self.task,
-                                    'scraper_name': self.scraper.config['SCRAPER_NAME']})
+                                    **self.scraper.log_extras()})
                 metadata_file.save(self, filename=filename + '_metadata.json')
 
     def _get_metadata(self):
@@ -207,7 +209,8 @@ class Download:
             dict: Data to be saved in the metadata file
         """
         metadata = {'task': self.task,
-                    'scraper': self.scraper.config['SCRAPER_NAME'],
+                    'scraper_name': self.scraper.config['SCRAPER_NAME'],
+                    'run_id': self.scraper.config['RUN_ID'],
                     'download_manifest': self._manifest,
                     }
         return metadata
@@ -224,7 +227,7 @@ class Download:
         """
         logger.debug(f"Setting proxy {proxy}",
                      extra={'task': self.task,
-                            'scraper_name': self.scraper.config['SCRAPER_NAME']})
+                            **self.scraper.log_extras()})
         if isinstance(proxy, dict) and 'http' in proxy and 'https' in proxy:
             # Nothing more to do
             return proxy
@@ -330,22 +333,16 @@ class Download:
             try:
                 r = self.session.request(http_method, url, **r_kwargs)
 
-                custom_status_message = None
                 if custom_source_checks:
                     for re_text, status_code, message in custom_source_checks:
                         if re.search(re_text, r.text):
                             r.status_code = status_code
-                            custom_status_message = message
-
-                if custom_status_message:
-                    status_message = custom_status_message
-                else:
-                    status_message = requests.status_codes._codes[r.status_code][0]
+                            r.reason = message
 
                 log_extra = {'url': r.url,
                              'method': http_method,
                              'status_code': r.status_code,
-                             'status_message': status_message,
+                             'reason': r.reason,
                              'headers': {'request': dict(r.request.headers),
                                          'response': dict(r.headers)},
                              'response_time': r.elapsed.total_seconds(),
@@ -353,14 +350,14 @@ class Download:
                              'num_tries': _try_count,
                              'max_tries': max_tries,
                              'task': self.task,
-                             'scraper_name': self.scraper.config['SCRAPER_NAME'],
+                             **self.scraper.log_extras(),
                              'proxy': proxy_used}
                 logger.info("Request finished", extra=log_extra)
 
                 if r.status_code != requests.codes.ok:
                     if (_try_count < max_tries
                        and r.status_code not in self._ignore_codes):
-                        r_kwargs = self.new_profile(**r_kwargs)
+                        r_kwargs = self.new_profile(failed_response=r, **r_kwargs)
                         request_method = self._set_http_method(http_method)
                         return request_method(url,
                                               max_tries=max_tries,
@@ -381,7 +378,7 @@ class Download:
 
             except Exception as e:
                 if _try_count < max_tries:
-                    r_kwargs = self.new_profile(**r_kwargs)
+                    r_kwargs = self.new_profile(failed_response=e.response, **r_kwargs)
                     request_method = self._set_http_method(http_method)
                     return request_method(url,
                                           max_tries=max_tries,
@@ -395,7 +392,7 @@ class Download:
                                             'num_tries': _try_count,
                                             'max_tries': max_tries,
                                             'task': self.task,
-                                            'scraper_name': self.scraper.config['SCRAPER_NAME'],
+                                            **self.scraper.log_extras(),
                                             'proxy': proxy_used})
                     raise DownloadValueError(f"Download failed: {str(e)}")
 
@@ -411,7 +408,7 @@ class Download:
         ua = self._get_user_agent(device_type)
         self.session.headers.update({'user-agent': ua})
 
-    def new_profile(self, **r_kwargs):
+    def new_profile(self, failed_response=None, **r_kwargs):
         """Rotate proxies and headers to retry the request again
         Users scraper can override this to rotate things their own way
 
@@ -429,17 +426,6 @@ class Download:
         self._set_session_ua()
 
         # Set new proxy
-        proxy_str = self._get_proxy(country=self.task.get('proxy_country'))
-        if 'proxy' in r_kwargs:
-            # Replace the request specific
-            r_kwargs['proxy'] = proxy_str
-
-        elif 'proxies' in r_kwargs:
-            # Replace the request specific
-            r_kwargs['proxies'] = proxy_str
-
-        else:
-            # Replace the session proxy
-            self.session.proxies = self._format_proxy(proxy_str)
+        r_kwargs['proxy'] = self._get_proxy(country=self.task.get('proxy_country'))
 
         return r_kwargs
